{%  if not deployment %}
<button class="btn btn-outline-secondary disabled">Migrate</button>
{% elif is_migrated %}
<button class="btn btn-outline-danger disabled">Migrated ✅</button>
{% else %}
<button
        hx-post="{{ url_for('AstroMigration.button_migrate', type=type, deployment=deployment, target=target) }}"
        class="btn btn-outline-primary">
    Migrate
</button>
{% endif %}
